minBy method
Returns the first element yielding the smallest value of the given
selector or null if there are no elements.
Implementation
T minBy(Comparable selector(T element)) => _minMaxBy(-1, selector);
Returns the first element yielding the smallest value of the given
selector or null if there are no elements.
T minBy(Comparable selector(T element)) => _minMaxBy(-1, selector);